'use strict';


// Declare app level module which depends on filters, and services

angular.module('startups', [
  'pascalprecht.translate',
  'ngRoute',
  'ngAnimate',
  'ngTouch',
  'configurator.filters',
  'configurator.services',
  'configurator.directives',
  'configurator.controllers',
  'ui.bootstrap',
  'angular-carousel',
  'LocalStorageModule',
  'infinite-scroll'
]).config(
        ['$routeProvider','localStorageServiceProvider', function($routeProvider, localStorageServiceProvider, localStorageService) {
            $routeProvider.when('/home', {templateUrl: 'partials/home.html', controller: 'HomeCtrl'});
            $routeProvider.when('/startups', {templateUrl: 'partials/startups.html', controller: 'StartupsCtrl'});
            $routeProvider.when('/startupsDetail', {templateUrl: 'partials/startupsDetail.html', controller: 'StartupsDetailCtrl'});
            $routeProvider.when('/events', {templateUrl: 'partials/events.html', controller: 'EventsCtrl'});
            $routeProvider.when('/eventDetail', {templateUrl: 'partials/eventsDetail.html', controller: 'EventsDetailCtrl'});
            $routeProvider.when('/about', {templateUrl: 'partials/about.html'});
            $routeProvider.when('/about_en', {templateUrl: 'partials/about_en.html'});
            $routeProvider.when('/einstellungen', {templateUrl: 'partials/einstellungen.html', controller: 'SettingsCtrl'});
            $routeProvider.when('/impressum', {templateUrl: 'partials/impressum.html'});
            $routeProvider.when('/impressum_en', {templateUrl: 'partials/impressum_en.html'});
            $routeProvider.otherwise({redirectTo: '/home'});

            localStorageServiceProvider.setPrefix('startups');
        }]
    )
.config(function($translateProvider) {
  $translateProvider.translations('en', {
    ALL:                      'ALL',
    MY_FAVORITES:             'My Favorites',
    NEXT_EVENT:               'Next events',
    STARTUP_NEWS:             'START-UP<br/>NEWS',
    LOAD_DATA:                'loading data.',
    ABOUT:                    'About',
    SETTINGS:                 'Settings',
    IMPRINT:                  'Imprint',
    CHANGE_LANGUAGE:          'Change Language',
    ENGLISH:                  'English',
    GERMAN:                   'German',
    DATA_UPDATE:              'Update data now',
    MORE_INFO:                'More infos >>>',
    INFO:                     'Info',
    PARTICIPATION_START_UPS:  'Participating start-ups',
    PARTICIPATOR:             'Participator:',
    START_UPS:                'Start-ups',
    CATEGORY:                 'Category:',
    ONLY_FAVORITES:           'Only favorites',
    START_UPS_CATEGORY:       'START-UP CATEGORIES',
    FAV:                      'Fav',
    ADDRESS:                  'Address:',
    EMAIL:                    'Email:',
    PHONE:                    'Phone:',
    FAX:                      'Fax:',
    CONTACT_AP:               'Contact person:',
    CONTACT:                  'Contact',
    NEWS:                     'News',
    FOUNDED:                  'founded:',
    AUTOMATIC:                'Automatic',
    DATE:                     'Date:',
    TIME:                     'Time:',
    SEARCH:                   'Search',
  });
  $translateProvider.translations('de', {
    ALL:                      'ALLE',
    MY_FAVORITES:             'Meine Favoriten',
    NEXT_EVENT:               'Nächste Events',
    STARTUP_NEWS:             'Neuigkeiten<br>der START-UPS',
    LOAD_DATA:                'Daten werden geladen.',
    ABOUT:                    'About',
    SETTINGS:                 'Einstellungen',
    IMPRINT:                  'Impressum',
    CHANGE_LANGUAGE:          'Sprache wechseln',
    ENGLISH:                  'Englisch',
    GERMAN:                   'Deutsch',
    DATA_UPDATE:              'Daten jetzt aktualisieren',
    MORE_INFO:                'Mehr Infos >>>',
    INFO:                     'Info',
    PARTICIPATION_START_UPS:  'Teilnehmende Start-ups',
    PARTICIPATOR:             'Teilnehmer:',
    START_UPS:                'Start-ups',
    CATEGORY:                 'Kategorie:',
    ONLY_FAVORITES:           'Nur Favoriten',
    START_UPS_CATEGORY:       'START-UPS Kategorien',
    FAV:                      'Fav',
    ADDRESS:                  'Adresse:',
    EMAIL:                    'Email:',
    PHONE:                    'Telefon:',
    FAX:                      'Fax:',
    CONTACT_AP:               'Ansprechpartner:',
    CONTACT:                  'Kontakt',
    NEWS:                     'News',
    FOUNDED:                  'gegründet:',
    AUTOMATIC:                'Automatisch',
    DATE:                     'Datum:',
    TIME:                     'Zeit:',
    SEARCH:                   'Suche',
  });
  
})
.run(
    function($rootScope, $location) {
        $rootScope.menuActive = function(url) {
            return $location.path() == url;
        }

        document.addEventListener('resume', function(){
            $rootScope.$broadcast('resume');
        }, false);

        document.addEventListener('backbutton', function(){
            $rootScope.$broadcast('backbutton');
        }, false);

    }


).factory('$translateLocalStorage', [
  '$window',
  '$translateCookieStorage',
  function ($window, $translateCookieStorage) {
    var localStorageAdapter = {
        get: function (name) {
          return $window.localStorage.getItem(name);
        },
        set: function (name, value) {
          $window.localStorage.setItem(name, value);
        }
      };
    var $translateLocalStorage = 'localStorage' in $window && $window.localStorage !== null ? localStorageAdapter : $translateCookieStorage;
    return $translateLocalStorage;
  }
]);

