'use strict';

/* Controllers */
var controllers = angular.module('configurator.controllers', []);

controllers.controller('MainCtrl', function MainCtrl($translate, $scope, $location, RestClient, $filter,
                                                     NotificationService, localStorageService, ImgCacheService, $timeout, $window) {

    var loadData = false;
    var defaultLanguage = 'de';
    if (navigator.globalization) {
        var lang = navigator.language.split("-");
        defaultLanguage = (lang[0]);
     //   alert( "current_lang: " + defaultLanguage );
    }

    /*
    var defaultLanguage = 'de';
    if (navigator.globalization) {
        navigator.globalization.getPreferredLanguage(
            function (language) { alert(language.value); defaultLanguage = language.value.split('-')[0]; alert(defaultLanguage); },
            function () {defaultLanguage = 'de';}
        );
    }
    */

    //alert("defaultLanguage: "+defaultLanguage);
    if (!localStorageService.get('language')) {

        localStorageService.add('language', defaultLanguage);
        localStorageService.add('language_auto', true);
        $translate.use(defaultLanguage);
        loadData = true;
    } else {
        if (localStorageService.get('language_auto')) {
            localStorageService.add('language', defaultLanguage);
            $translate.use(defaultLanguage);
        } else {
            $translate.use(localStorageService.get('language'));
        }
    }
    console.log("Storage language: " + localStorageService.get('language'));
    $scope.scrollPos = {}; // scroll position of each view
    $scope.history = []; // path history

    jq(window).on('scroll', function() {
        if ($scope.okSaveScroll) { // false between $routeChangeStart and $routeChangeSuccess
            $scope.scrollPos[$location.path()] = jq(window).scrollTop();
        }
    });

    $scope.setHistory = function() {
        $scope.history = [];
    }

    $scope.scrollClear = function(path) {
        $scope.scrollPos[path] = 0;
    }

    $scope.scrollClearAll = function() {
        $scope.scrollPos = {};
    }

    $scope.$on('$routeChangeStart', function() {
        $scope.okSaveScroll = false;

        if ($location.path() == '/about') {
            if (localStorageService.get('language') == 'en') {
                $location.path('/about_en');
            }
            $scope.title = "About";
        } else if ($location.path() == '/impressum') {
            $scope.title = "Impressum";
            if (localStorageService.get('language') == 'en') {
                $location.path('/impressum_en');
                $scope.title = "Imprint";
            }
        }
    });

    $scope.$on('$routeChangeSuccess', function(currentRoute, previousRoute) {
        $timeout(function() { // wait for DOM, then restore scroll position

            if ($scope.history.indexOf($location.path()) == -1) $scope.history.push($location.path());

            var pos = $scope.scrollPos[$location.path()] ? $scope.scrollPos[$location.path()] : 0;
            $window.scrollTo(0, pos);
            $scope.okSaveScroll = true;
        }, 0);
    });

    $scope.historyBack = function () {
        var prevUrl = $scope.history.length > 1 ? $scope.history.splice(-2)[0] : "/";
        $location.path(prevUrl);
    };

    $scope.gotoLast = function() {
        window.history.back();
    }
    
    $scope.dataLoaded = false;
    $scope.reloadData = false;
    $scope.startups;
    $scope.selectedFilter = [];
    $scope.selectedStartup;
    $scope.search = {};

    //$scope.requestImagesLength = 0;
    //$scope.imagesCached = 0;
    $scope.percent;

    $scope.sync = 3; // immer

    $scope.setDataLoaded = function(v) {
        $scope.dataLoaded = v;
    };

    $scope.setReloadData = function(v) {
        $scope.reloadData = v;
    };

    $scope.setPercent = function(v) {
        $scope.percent = v;
    };

    if (localStorageService.get('sync')) {
        $scope.sync = localStorageService.get('sync');
    } else {
        localStorageService.set('sync', $scope.sync);
    }

    var successLoad = function(result) {
        localStorageService.add('Startups',result);
    }

    var errorLoad = function() {
        if (localStorageService.get('Startups')) {
            $scope.startups = localStorageService.get('Startups');
            $scope.dataLoaded = true;

            if (navigator.splashscreen) {
                navigator.splashscreen.hide();
            }
        } else {
            // no connection and no localstorage
            if (localStorageService.get('language') == 'de') {
                // GERMAN
                NotificationService.alert("Um aktuelle Daten zu Laden wird eine Internetverbindung benötigt. Bitte stellen Sie eine Verbindung zum Internet her.",
                    "Verbindungsfehler", "Erneut versuchen",
                    function() {
                        $scope.loadAll();
                    }
                );
            } else {
                // ENGLISH
                NotificationService.alert("Internet connection needed. Please connect to the internet.",
                    "Connection error", "Try again",
                    function() {
                        $scope.loadAll();
                    }
                );
            }
        }
    }

    $scope.loadAll = function() {
        console.log("loadAll");

        $scope.startups = RestClient.query({action: 'getAllStartups'}, successLoad, errorLoad);

        $scope.categories = RestClient.query({action: 'getCategories'},
            function(result) {
                localStorageService.add('Categories',result);
            },
            function() {
                if (localStorageService.get('Categories')) {
                    $scope.categories = localStorageService.get('Categories');
                }
            });

        $scope.news = RestClient.queryNews({action: 'getAllNews'},
            function(result) {
                localStorageService.add('News',result);
            },
            function() {
                if (localStorageService.get('News')) {
                    $scope.news = localStorageService.get('News');
                }
            });

        $scope.events = RestClient.query({action: 'getAllEvents'},
            function(result) {
                localStorageService.add('Events',result);
            },
            function() {
                if (localStorageService.get('Events')) {
                    $scope.events = localStorageService.get('Events');
                }
            });

        $scope.imageIds = RestClient.queryImage({action: 'getSyncImageIDs'}, // getAllImageIds
            function(result) {
                var newImageIds = [];
                var requestImages = result.Images;

                // is image_id in localStorage
                if (localStorageService.get('ImageIds')) {
                    var localStorageImageIds = localStorageService.get('ImageIds');
                    angular.forEach(result.Images, function(value, key) {
                        var isIn = false;
                        for (var i = 0; i <= localStorageImageIds.Images.length - 1; i++) {
                            if (localStorageImageIds.Images[i].image_id == value.image_id) {
                                isIn = true;
                                break;
                            }
                        }
                        if (!isIn) newImageIds.push(value)
                    });
                    requestImages = newImageIds;
                }

                var requestImagesLength = requestImages.length;
                var imagesCached = 0;

                if (requestImagesLength == imagesCached) {
                    $scope.dataLoaded = true;
                    if (navigator.splashscreen) {
                        $timeout(function() {
                            navigator.splashscreen.hide();
                        }, 500);
                    }
                } else {

                    var _loadimg = function(id) {
                        if (requestImages[id]) {
                            //console.log("value.image_id: " + requestImages[id].image_id);
                            ImgCacheService.cache(requestImages[id].image_id, function() {
                                    imagesCached++;
                                    $scope.percent = Math.round(imagesCached * 100 / requestImagesLength) + "%";
                                    if (requestImagesLength == imagesCached) {
                                        //console.log("value.image_id: " + requestImages[id].image_id + "imagesCached: " + imagesCached + " requestImagesLength: " + requestImagesLength)
                                        $scope.dataLoaded = true;
                                        $scope.lazyImageLoad();
                                    }
                                    $scope.$apply();
                                    _loadimg(imagesCached)
                                }
                                , function() {
                                    //console.log("error : " + value.image_id + "imagesCached: " + imagesCached + " requestImagesLength: " + requestImagesLength)
                                    imagesCached++;
                                    if (requestImagesLength == imagesCached) {
                                        $scope.dataLoaded = true;
                                        $scope.lazyImageLoad();
                                    }
                                    $scope.$apply();
                                    _loadimg(imagesCached)
                                }
                            );
                        }
                    }

                    _loadimg(0);

                    if (navigator.splashscreen) navigator.splashscreen.hide();
                }

                localStorageService.add('ImageIds',result);
            },
            function() {
                if (localStorageService.get('ImageIds')) {
                    $scope.imageIds = localStorageService.get('ImageIds');
                }
            });

        $scope.syncNews();
    }

    ImgCacheService.init();

    $scope.$on('cacheCreated', function(event) {

        console.log('MainCtrl ImgCache cacheCreated $scope.sync: ' + $scope.sync);
        //console.log("loadData : " + loadData);
        if (loadData) {
            $scope.categories = RestClient.query({action: 'getCategories'},
            function(result) {
                console.log("reloadData only check connection");
                $scope.clearCache(function() {
                    $scope.setPercent('0%');
                    console.log("clearLocalStorage");
                    localStorageService.remove('Events');
                    localStorageService.remove('ImageIds');
                    localStorageService.remove('News');
                    localStorageService.remove('Startups');
                    localStorageService.remove('BackgroundImageIDs');
                    $timeout(function(){
                        $location.path('home');
                        $scope.setDataLoaded(false);
                        $scope.loadAll();
                    }, 200);
                });
                //$scope.setReloadData(true);
            },
            function() {
                // no connection and no localstorage
                if (localStorageService.get('language') == 'de') {
                    // GERMAN
                    NotificationService.alert("Um aktuelle Daten zu Laden wird eine Internetverbindung benötigt. Bitte stellen Sie eine Verbindung zum Internet her.",
                        "Verbindungsfehler", "Ok",
                        function() {

                        }
                    );
                } else {
                    // ENGLISH
                    NotificationService.alert("Internet connection needed. Please connect to the internet.",
                        "Connection error", "Ok",
                        function() {

                        }
                    );
                }
            });
        } else {
            $scope.loadAll();
        }
        /*
        if ($scope.sync == 3) { // immer
            $scope.loadAll();
        } else if ($scope.sync == 1) { // manuell

            loadFromStorage();

        } else { // wifi
            console.log('MainCtrl ImgCache cacheCreated checkConnection(): ' + checkConnection());
            if (checkConnection() == 'wifi') {
                $scope.loadAll();
            } else {
                loadFromStorage();
            }
        }
        */
    });

    $scope.lazyImageLoad = function() {
        //console.log("start lazyImageLoad");
        RestClient.queryImage({action: 'getBackgroundImageIDs'},

            function(result) {
                // is image_id in localStorage
                var newImageIds = [];
                var requestImages = result.Images;

                var lsBackgroundImageIDs = localStorageService.get('BackgroundImageIDs')
                if (lsBackgroundImageIDs) {
                    angular.forEach(requestImages, function(value, key) {
                        var isIn = false;
                        for (var i = 0; i <= lsBackgroundImageIDs.Images.length - 1; i++) {
                            if (lsBackgroundImageIDs.Images[i].image_id == value.image_id) {
                                isIn = true;
                                break;
                            }
                        }
                        if (!isIn) newImageIds.push(value)
                    });
                    requestImages = newImageIds;
                }

                var cached = 0;
                var _loadimg = function(id) {
                    if (requestImages[id]) {
                        var id = requestImages[id].image_id;
                        ImgCacheService.cache(id, function() {
                                cached++;
                                _loadimg(cached);
                            }, function() {
                                cached++;
                                _loadimg(cached);
                            }
                        );
                    }
                }

                _loadimg(0);
                localStorageService.add('BackgroundImageIDs',result);
            },
            function() {
                console.log("Error call RestClient getBackgroundImageIDs")
            });

    }

    $scope.clearCache = function(success) {
        ImgCache.clearCache(
            function(){
                success();
            },
            function(){
                console.log("cannot clearCache")
            }
        )
    }

    $scope.setFilter = function (val) {
        $scope.selectedFilter = [];
        // if favorites select all other cats, too
        if(val == '99') {
            $scope.selectedFilter = ['1', '2', '3', '4', '5', '6', '99'];
        }
        $scope.selectedFilter.push(val);
        $location.path("/startups");
    }

    $scope.resetFilter = function (val) {
        $scope.selectedFilter = ["0"];

        angular.forEach($scope.categories, function(value, key){
            $scope.selectedFilter.push(value.Category.id);
        });
        // unset fav
        var pos = $scope.selectedFilter.indexOf('99');
        if(pos >= 0) {
            $scope.selectedFilter.splice(pos,1);
        }
        $location.path("/startups");
    }

    $scope.goto = function(url) {
        $location.path(url);
    }

    $scope.setSelectedStartup = function (item) {
        $scope.selectedStartup = item;
    }

    $scope.showStartUpDetail = function (item) {
        $scope.selectedStartup = item;

        $timeout(function(){
            $location.path("/startupsDetail");
        }, 50);
    }

    $scope.toggleFav = function(startup_id) {
        var favList = [];
        if(!(favList = localStorageService.get('FavouriteStartups'))) {
            localStorageService.set('FavouriteStartups', []);
        }

        //check if startup id is in favs
        var pos = favList.indexOf(startup_id);

        if(pos >= 0) {
            // we have to remove it
            favList.splice(pos, 1);
        }
        else {
            // we add a new fav
            favList.splice(pos,0,startup_id);
        }

        console.log(favList);

        localStorageService.add('FavouriteStartups',favList);
    }

    $scope.isFav = function(startup_id) {
        if(localStorageService.get('FavouriteStartups')) {
            return localStorageService.get('FavouriteStartups').indexOf(startup_id) >= 0;
        }
        return false;
    }

    $scope.setStartUpDetail = function (id) {
        angular.forEach($scope.startups, function(value, key){
            if (value.Startup.id == id) {
                $scope.selectedStartup = value;
                return;
            }
        });
        $location.path("/startupsDetail");
    }

    $scope.openWindow = function(url) {
        window.open(url, '_system', 'location=no');
    }

    $scope.setEventDetail = function (item) {
        $scope.selectedEvent = item;
    }

    $scope.showEventDetail = function (item) {
        $scope.selectedEvent = item;
        $timeout(function(){
            $location.path("/eventDetail");
        }, 50);
    }

    $scope.openSystem = function(url) {
        window.open(url.replace(/\s/g, ''), '_system');
    }

    $scope.syncNews = function() {
        var syncinterval = 15 * 60; // in sekunden

        // last sync time
        var lastsync = localStorageService.get('lastsync');
        var newsync = Date.now();

        if ((newsync - lastsync) / 1000 > syncinterval) {

            $scope.imageIds = RestClient.queryImage({action: 'getAllImageIds'},
                function(result) {
                    localStorageService.add('ImageIds',result);
                });

            $scope.news = RestClient.queryNews({action: 'getAllNews'},
                function(result) {
                    console.log("dosync lastsync: " + lastsync);
                    console.log("newsync: " + newsync);
                    localStorageService.add('News',result);
                },
                function() {
                    if (localStorageService.get('News')) {
                        $scope.news = localStorageService.get('News');
                    }
                });

            localStorageService.set('lastsync', newsync);
        }

        $timeout(function(){
            $scope.syncNews();
        }, syncinterval * 1000);

    }

    function loadFromStorage() {
        $scope.startups = localStorageService.get('Startups');
        $scope.events = localStorageService.get('Events');
        $scope.news = localStorageService.get('News');
        $scope.categories = localStorageService.get('Categories');
        $scope.dataLoaded = true;

        $scope.$apply();

        if (navigator.splashscreen) {
            navigator.splashscreen.hide();
        }
    }

    $scope.$on('resume', function(next, current) {
        //$scope.loadAll();

        /*
        console.log('resume $scope.sync: ' + $scope.sync);

        if ($scope.sync == 3) { // immer
            $scope.loadAll();
        } else if ($scope.sync == 1) { // manuell

            loadFromStorage();

        } else { // wifi
            console.log('MainCtrl ImgCache cacheCreated checkConnection(): ' + checkConnection());
            if (checkConnection() == 'wifi') {
                $scope.loadAll();
            } else {
                loadFromStorage();
            }
        }
        */

    });

    $scope.setSync = function(v) {
        console.log("setSync: " + v);
        $scope.sync = v;
        localStorageService.set('sync', $scope.sync);
    }

    $scope.checkConnection = function() {
       // alert("navigator.connection :" + navigator.connection);
        if (navigator.connection) {
            var networkState = navigator.connection.type;

            var states = {};
            states[Connection.UNKNOWN]  = 'Unknown connection';
            states[Connection.ETHERNET] = 'Ethernet connection';
            states[Connection.WIFI]     = 'WiFi connection';
            states[Connection.CELL_2G]  = 'Cell 2G connection';
            states[Connection.CELL_3G]  = 'Cell 3G connection';
            states[Connection.CELL_4G]  = 'Cell 4G connection';
            states[Connection.CELL]     = 'Cell generic connection';
            states[Connection.NONE]     = 'No network connection';

            //alert("networkState :" + networkState);

            return networkState;
        }
    }

    $scope.$on('backbutton', function() {
        var prevUrl = $scope.history.length > 1 ? $scope.history.splice(-2)[0] : "/";
        $location.path(prevUrl);
        $scope.$apply();
    });

});

controllers.controller('StartupsCtrl', function StartupsCtrl($scope, $location, RestClient, $timeout, ReactService, localStorageService) {

    $scope.title = "START-UPS";

    $scope.isCollapsed = true;
    if (!localStorageService.get('filterCollapsed')) {
        $scope.isCollapsed = false;

        var timer = $timeout( function(){
            $scope.isCollapsed = true;
        }, 2000);

        localStorageService.set('filterCollapsed',true);
    }

    $scope.setSelectedStartup(null);
    $scope.searchTextDebounced = "";

    angular.forEach($scope.startups, function(value, key) {
        if (localStorageService.get('language') == 'en') {
            value.Startup.description_output       = value.Startup.description_en;
            value.Startup.description_short_output = value.Startup.description_short_en;
        } else {
            value.Startup.description_output       = value.Startup.description;
            value.Startup.description_short_output = value.Startup.description_short;
        }
    });

    $scope.displayStartups = $scope.startups.slice(0, 9);
    $scope.startupsPaging = function () {
        var last = $scope.displayStartups.length - 1;
        var lastTotal = $scope.startups.length - 1;

        if(lastTotal - last <= 0)
            return;

        var add = Math.min(5, lastTotal - last);
        for(var i = 1; i <= add; i++) {
            $scope.displayStartups.push($scope.startups[last + i]);
        }
    }

    $scope.fillListUntilVisible = ReactService.debounce(function () {
        $scope.$evalAsync(function() {

            if ($location.path() != '/startups') return;

            var $startups = jq('.list-container .startups');
            var $entries = $startups.children();

            var entryHeight = jq($entries[0]).outerHeight(true);
            var overlayCount = jq('.list-container .overlay li').length;

            var currentScrollPosition = window.scrollY + window.innerHeight - $startups.offset().top;
            var currentVisibleCount = Math.ceil(Math.max(0, currentScrollPosition) / entryHeight);

            if(!currentVisibleCount || currentVisibleCount <= 0) {
                return;
            }

            var lastVisibleStartupName = jq('h2', $entries[currentVisibleCount]).text();

            var lastIndex = $scope.startups.length;
            for(var i = 0; i < $scope.startups.length; i++) {
                if($scope.startups[i].Startup.name == lastVisibleStartupName) {
                    lastIndex = i + 1;
                    break;
                }
            }

            $scope.displayStartups = $scope.startups.slice(0, lastIndex);
        });
    }, 1000, false);

    $scope.inFilter = function (v) {
        var idx = $scope.selectedFilter.indexOf(v);

        if (idx > -1) {
            return true;
        } else {
            return false;
        }
    }

    $scope.isInCategory = function (v) {
        var isIn = false;
        angular.forEach(v.Category, function(value, key){
            if ($scope.inFilter(value.id)) {
                isIn = true;

            }
        });


        // do not show if not in favs and fav is set as filter
        if(!$scope.isFav(v.Startup.id) && $scope.selectedFilter.indexOf('99') >= 0) {
            isIn = false;
        }

        return isIn;
    };

    $scope.setFilter = function (val) {
        $timeout.cancel(timer);

        var removeAll = true;

        // is currently selected
        var idx = $scope.selectedFilter.indexOf(val);
        if (idx > -1) {
            $scope.selectedFilter.splice(idx, 1);
        } else {
            $scope.selectedFilter.push(val);
            
            var filterIndex = $scope.selectedFilter.indexOf(99);
            if ($scope.allCategoriesSelected() && filterIndex == -1) {
                $scope.selectedFilter.push('0');
                removeAll = false;
            }
        }

        if(removeAll) {
            var allIndex = $scope.selectedFilter.indexOf('0');
            if (allIndex > -1) {
                $scope.selectedFilter.splice(allIndex, 1);
            }
        }
        
        $scope.fillListUntilVisible();
    }

    $scope.allCategoriesSelected = function() {
        var count = $scope.selectedFilter.length;

        // if fav is in filter we need a count of 7
        var filterIndex = $scope.selectedFilter.indexOf(99);
        if(filterIndex >= 0 && count == 7) {
            return true;
        } 

        // no filter, but all other categories are selected
        if(count == 6) {
            return true;
        }
        
        return false;
    }

    $scope.$on('$routeChangeSuccess', function() {
        $scope.fillListUntilVisible();
    });

    var searchHandler = ReactService.debounce(function(value) {
            if(typeof value != "undefined") {
                $scope.searchTextDebounced = value;
                $scope.fillListUntilVisible();
            }
        }, 500, false);

    $scope.$watch('search.text', searchHandler);


});

controllers.controller('StartupsDetailCtrl', function StartupsDetailCtrl($scope, ImgCacheService, localStorageService) {
    $scope.title = "START-UPS";
    if (localStorageService.get('language') == 'en') {
        $scope.description = $scope.selectedStartup.Startup.description_en;
    } else {
        $scope.description = $scope.selectedStartup.Startup.description;
    }
    $scope.isCollapsedInfo = false;
    $scope.isCollapsedContact = true;
    $scope.isCollapsedNews = true;

    $scope.tabs = {ypos: 0}

    $scope.isSwipe = false;
    if ($scope.selectedStartup && $scope.selectedStartup.Images.length > 1) {
        $scope.isSwipe = true;
        $scope.showSlider = true;

        var hasConnection = true;

        if ($scope.checkConnection() && $scope.checkConnection() == 'none') {
            hasConnection = false;
        }

        $scope.$on('ImageInCache', function(event, msg) {
            if (!hasConnection && !msg.inCache) {
                $scope.showSlider = false;
            }
        });

        ImgCacheService.isInCached($scope.selectedStartup.Images[0].image_id);
    }

    angular.forEach($scope.selectedStartup.Contact, function(value, key) {
        if (localStorageService.get('language') == 'en') {
            value.role_output    = value.role_en;
        } else {
            value.role_output    = value.role;
        }
    });

    $scope.$on('ErrorImageLoad', function(event) { // gallery image 2,3, ...
        $scope.isSwipe = false;
        $scope.$apply();
    });
});

controllers.controller('EventsCtrl', function EventsCtrl($scope) {

    $scope.title = "EVENTS";
    $scope.setEventDetail(null);

});

controllers.controller('EventsDetailCtrl', function EventsDetailCtrl($scope, ImgCacheService, localStorageService) {

    $scope.title = "EVENTS";
   // console.log($scope.selectedEvent.Startup[0].description_short);
   /*
    if (localStorageService.get('language') == 'en') {
        $scope.description_short = $scope.selectedEvent.Startup[0].description_short_en;
    } else {
        $scope.description_short = $scope.selectedEvent.Startup[0].description_short;
    }
    */
    $scope.isCollapsedInfo = false;
    $scope.isCollapsedNews = false;

    $scope.tabs = {ypos: 0}

    $scope.isSwipe = false;
    if ($scope.selectedEvent && $scope.selectedEvent.Images.length > 1) {
        $scope.isSwipe = true;

        //console.log('EventsDetailCtrl checkConnection(): ' + $scope.checkConnection());

        $scope.showSlider = true;
        var hasConnection = true;
        if ($scope.checkConnection() && $scope.checkConnection() == 'none') {
            hasConnection = false;
        }

        $scope.$on('ImageInCache', function(event, msg) {
            //console.log('ImageInCache: ' + msg.inCache + ' ' + msg.imageId);
            if (!hasConnection && !msg.inCache) {
                $scope.showSlider = false;
            }
        });

        ImgCacheService.isInCached($scope.selectedEvent.Images[0].image_id);
    }

    $scope.$on('ErrorImageLoad', function(event) { // gallery image 2,3, ...
        $scope.isSwipe = false;
        $scope.$apply();
    });
});

controllers.controller('HomeCtrl', function HomeCtrl($scope, $window, localStorageService) {
    $scope.title = "HOME";

    $scope.setSelectedStartup(null);
    $scope.setEventDetail(null);
    $scope.scrollClearAll();
    $scope.setHistory();

    angular.forEach($scope.categories, function(value, key) {
        if (localStorageService.get('language') == 'en') {
            value.Category.name_output    = value.Category.name_en;
        } else {
            value.Category.name_output    = value.Category.name;
        }
    });

});


controllers.controller('SettingsCtrl', function SettingsCtrl($scope, $timeout, localStorageService, $location, RestClient, NotificationService) {
    $scope.title = "SETTINGS";
    $scope.active_en = "";
    $scope.active_de = "";
    $scope.active_auto = "";
    if (!localStorageService.get('language_auto')) {
        $scope['active_' + localStorageService.get('language')] = "active";
    } else {
        $scope.active_auto = "active";
    }
   // $scope.btnText = "Daten jetzt aktualisieren";

    $scope.clearLocalStorage = function() {
        console.log("clearLocalStorage");
        localStorageService.remove('Events');
        localStorageService.remove('ImageIds');
        localStorageService.remove('News');
        localStorageService.remove('Startups');
        localStorageService.remove('BackgroundImageIDs');
    }

    $scope.reloadData = function() {
        // only check connection
        $scope.categories = RestClient.query({action: 'getCategories'},
            function(result) {
                console.log("reloadData only check connection");
                $scope.clearCache(function() {
                    $scope.setPercent('0%');
                    $scope.clearLocalStorage();
                    $timeout(function(){
                        $location.path('home');
                        $scope.setDataLoaded(false);
                        $scope.loadAll();
                    }, 200);
                });
                //$scope.setReloadData(true);
            },
            function() {
                // no connection and no localstorage
                if (localStorageService.get('language') == 'de') {
                    // GERMAN
                    NotificationService.alert("Um aktuelle Daten zu Laden wird eine Internetverbindung benötigt. Bitte stellen Sie eine Verbindung zum Internet her.",
                        "Verbindungsfehler", "Ok",
                        function() {

                        }
                    );
                } else {
                    // ENGLISH
                    NotificationService.alert("Internet connection needed. Please connect to the internet.",
                        "Connection error", "Ok",
                        function() {

                        }
                    );
                }
            });
    }

});


controllers.controller('LangCtrl', function($scope,$translate, localStorageService){
    $scope.changeLang = function (langKey) {
        localStorageService.add('language_auto', '');
        if (langKey != 'auto'){
            $translate.use(langKey);
            localStorageService.add('language', langKey);
        } else if (langKey == 'auto') {
            var defaultLanguage = localStorageService.get('language');

            if (navigator.globalization) {
                var lang = navigator.language.split("-");
                defaultLanguage = (lang[0]);
             //   alert( "current_lang: " + defaultLanguage );
            }

            /*
            if (navigator.globalization) {
                navigator.globalization.getPreferredLanguage(
                    function (language) { defaultLanguage = language.value.split('-')[0]; },
                    function () {defaultLanguage = 'de';}
                );
            }
            */
            $translate.use(defaultLanguage);
            localStorageService.add('language', defaultLanguage);
            localStorageService.add('language_auto', true);
        }
        $scope.active_en = "";
        $scope.active_de = "";
        $scope.active_auto = "";
        $scope['active_' + langKey] = "active";
    };
    $scope.getCurrentLanguage = function () {
        $translate.preferredLanguage();
    };
});



