'use strict';

/* Directives */


var directives = angular.module('configurator.directives', []);

directives.directive('sizeColumn', function($timeout) {

    return function(scope, element, attrs) {

        if (scope.$last) { // scope is ng-repeat (ng-repeat creates own scope)

            scope.$watch('obj', function(){
                $timeout(function(){
                    jq(element).parent().children().css('height', jq(element).parent().height());
                }, 100);

            });

        }

    };

});

directives.directive('onFinishRender', function ($timeout) {
    return {
        restrict: 'A',
        link: function (scope, element, attr) {

            if (scope.$last === true) {
                $timeout(function () {
                    scope.$emit('ngRepeatFinished');
                }, 0);
            }
        }
    }
});

directives.directive('slideCollapse', function($transition, $timeout, $window) {

    return {
        scope: {
            tabs: '=',
            slideCollapse: '='
        },
        link: function(scope, element, attrs) {

            var initialAnimSkip = true;
            var height =  jq(element).height();
            var currentYpos = 0;
            var currentTransition;

            function doTransition(change) {
                var newTransition = $transition(element, change);
                if (currentTransition) {
                    currentTransition.cancel();
                }
                currentTransition = newTransition;
                newTransition.then(newTransitionDone, newTransitionDone);
                return newTransition;

                function newTransitionDone() {
                    // Make sure it's this transition, otherwise, leave it alone.
                    if (currentTransition === newTransition) {
                        currentTransition = undefined;
                    }
                }
            }

            function down(ypos) {
                if (initialAnimSkip) {
                    initialAnimSkip = false;
                    element.css({WebkitTransform: 'translate3d(0,'+ypos+'px,0)'});
                } else {
                    element.addClass('tabanimopen');

                    setWindowSize(-1);

                    doTransition({ WebkitTransform: 'translate3d(0,'+ypos+'px,0)'}).then(function(){

                        if (scope.tabs.tabid == attrs.tabid) {
                            var _scrollTo = jq(element).offset().top - 80 - 40;
                            //console.log("down starty:  _scrollTo: " + _scrollTo);
                            jq("body").animate({scrollTop:  _scrollTo}, 500, 'swing', function(){
                                $timeout(function(){
                                    //setWindowSize(-1);
                                }, 100);
                            });
                        }
                    });
                }
            }

            function up(ypos) {
                if (initialAnimSkip) {
                    initialAnimSkip = false;
                    element.css({WebkitTransform: 'translate3d(0,'+ypos+'px,0)'});

                    jq(".scrollcontent").height(jq(".scrollcontent").height() - height + 40);
                    //console.log('jq(".scrollcontent").height(): ' + jq(".scrollcontent").height());
                } else {
                    element.addClass('tabanimopen');

                    doTransition({ WebkitTransform: 'translate3d(0,'+ypos+'px,0)'}).then(function(){
                        //jq(".scrollcontent").height(jq(".scrollcontent").height() - height);
                        if (scope.tabs.tabid == attrs.tabid) {

                            var _scrollTo = jq("body").scrollTop() - height;

                            //console.log("body.scrollTop:" + jq("body").scrollTop())
                            //console.log("up starty: " + jq(element).offset().top +  " _scrollTo: " + _scrollTo);

                            jq("body").animate({scrollTop:  _scrollTo }, 500, 'swing', function(){
                                $timeout(function(){
                                   setWindowSize(1);
                                }, 100);
                            });
                        }
                    });

                }
            }

            function setWindowSize(dir) {
                if (scope.tabs.tabid == attrs.tabid ) {
                    //console.log('setWindowSize: ' + scope.tabs.tabid + ':' + attrs.tabid);
                    //console.log('jq(".scrollcontent").height(): ' + jq(".scrollcontent").height());

                    var h = jq(".scrollcontent").height() - (height) * dir;
                    jq(".scrollcontent").height(h);
                }
            }

            $timeout(function(){
                scope.$watch("slideCollapse", watch);
            }, 0);

            var watch = function (shouldCollapse) {
                if (shouldCollapse) {
                    height =  jq(element).height();

                    if (initialAnimSkip) {
                        currentYpos = scope.tabs.ypos;
                    }

                    currentYpos = currentYpos - height + 40;
                    scope.tabs.ypos = currentYpos;

                    if (!initialAnimSkip) {
                        scope.tabs.ypos = -height + 40;
                    }

                    scope.tabs.tabid = attrs.tabid;
                    scope.tabs.dir = 'up';

                    up(currentYpos);
                } else {
                    height =  jq(element).height();

                    currentYpos = currentYpos + height - 40;

                    scope.tabs.ypos = height - 40;
                    scope.tabs.tabid = attrs.tabid;
                    scope.tabs.dir = 'down';

                    if (initialAnimSkip) {
                        currentYpos = 0;
                        scope.tabs.ypos = currentYpos;
                    }

                    down(currentYpos);
                    initialAnimSkip = false;
                }
            }

            scope.$watch("tabs", function(newValue, oldValue) {
                if (initialAnimSkip) return;

                if (newValue) {
                    if (attrs.tabid > newValue.tabid) {
                        //console.log("$watch tabid:" + newValue.tabid + ' ypos:' + newValue.ypos + " currentYpos: " + currentYpos);
                        currentYpos += newValue.ypos;

                        if (newValue.dir == 'up') {
                            up(currentYpos);
                        } else {
                            down(currentYpos);
                        }
                    }
                }
            }, true);

        }
    };
});


directives.directive('cachedImage', ['ImgCacheService','$rootScope','$timeout', function(ImgCacheService, $rootScope, $timeout) {
    return {

        link: function($scope, element, attrs) {

            var _src = element.attr('src');

            jq(element).error(function(){
                element.attr('src', _src);

                if (attrs.cachedImageHide) { // only carousel slider
                    jq(this).hide();
                    $scope.$emit("ErrorImageLoad");
                }
            })

            if (attrs.cachedImage) {
                var url = "https://tech-start-ups-bayern-app.evobis.de/api/getImage/" +  attrs.cachedImage;
                ImgCacheService.useCached(element, attrs.cachedImage);
            }

            attrs.$observe("watchRandomImage", function(value) {
                if (attrs.watchRandomImage) {
                    var url = "https://tech-start-ups-bayern-app.evobis.de/api/getImage/" +  attrs.cachedImage;
                    ImgCacheService.useCached(element, attrs.cachedImage);
                }
            });

            /*)
            if (attrs.cachedImageSliderHide) {
                $rootScope.$on('ErrorImageLoad', function(event, id) {
                    if (attrs.cachedImageSliderHide == id) { // only carousel slider
                        console.log("ErrorImageLoad: " + id);
                        //jq('.rn-carousel-container').hide();
                    }
                });
            }
            */

        }
    };
}]);



directives.directive('hideIndicator', function ($timeout) {
    return {
        restrict: 'A',
        link: function (scope, element, attr) {

            var show = function(v){
                if (v) {
                    jq('.rn-carousel-indicator').show();
                } else {
                    jq('.rn-carousel-indicator').hide();
                }
            }

            var t;
            scope.$watch('isSwipe', function(newValue) {
                $timeout.cancel(t);
                t = $timeout(function(){
                    show(newValue);
                },200);
            });
        }
    }
});

directives.directive('focusSearch', function () {
    return {
        restrict: 'A',
        link: function (scope, element, attr) {

            if (navigator.userAgent.match(/(iPod|iPhone|iPad)/)) {
                jq(element).on('focus', function(){
                    jq('#footer').hide();
                });

                jq(element).on('blur', function(){
                    jq('#footer').show();
                });
            }

        }
    }
});

directives.directive('randomTeaser', ['localStorageService', '$animate', '$timeout', function(localStorageService, $animate, $timeout) {
    return {
        restrict: 'A',
        transclude: true,
        scope: {
            val: '=',
            startups: '='
        },
        template: '<div class="anim" ng-click="$parent.showStartUpDetail(startup)" ng-class="{\'clickactive\': $parent.selectedStartup && $parent.selectedStartup == startup}">' +
            '<img src="img/200x200.png" cached-image="{{startup.Startup.main_image_id}}" watch-random-image="{{startup.Startup.main_image_id}}" />' +
            '<div class="text">' +
            '<h2>{{startup.Startup.name}}</h2>' +
            '<p>{{startup.Startup.description_short_translate}}</p></div>',

        link: function(scope, element, attrs) {

            var initial = 0;
            var randomTimer;
            var random = function() {
                var ele = jq(element).find('.anim');

                if(ele.hasClass('fade')) {
                    $animate.removeClass(ele, 'fade');
                }

                $timeout(function() {
                    jq(element).find('img').attr('src','img/200x200.png');
                    var r = Math.floor(Math.random() * scope.startups.length);
                    scope.startup = scope.startups[r];
                    if (localStorageService.get('language') == 'en') {
                        scope.startup.Startup.description_short_translate = scope.startup.Startup.description_short_en;
                    } else {
                        scope.startup.Startup.description_short_translate = scope.startup.Startup.description_short;
                    }
                    $animate.addClass(ele, 'fade');
                }, initial);

                randomTimer = $timeout(function() {
                    initial = 300;
                    random();
                }, attrs.randomTeaser * 1000);
            }

            scope.$watch('startups.length', function(newValue, oldValue) {
                if (newValue) {
                   random();
                }
            });

            scope.$on("$destroy", function(event) {
                $timeout.cancel(randomTimer);
            });

        }
    };
}]);