'use strict';

/* Services */


var services = angular.module('configurator.services', ['ngResource']);

services.service('RestClient',

    function($resource, $http) {

         var url = "https://tech-start-ups-bayern-app.evobis.de/api/:action/:id";
        //var url = "http://startup.local/api/:action/:id";

        return $resource(url, {}, {
            query: {method:'GET', params:{action:''}, isArray: true},
            queryImage: {method:'GET', params:{action:'',id:''}, isArray: false},
            queryNews: {method:'GET', params:{action:''}, isArray: false}
        });

    }

);

services.service("NotificationService", function () {
    return {
        alert: function (message, title, buttonText, buttonAction) {
            if (navigator.notification) {
                navigator.notification.alert(message,
                    buttonAction,
                    title,
                    buttonText);
            }
        }
    }
});


services.service("ImgCacheService", function ($rootScope, $timeout) {
    return {

        init: function (success) {

            console.log("ImgCacheService init");

            // write log to console
            ImgCache.options.debug = true;

            // increase allocated space on Chrome to 50MB, default was 10MB
            ImgCache.options.chromeQuota = 50*1024*1024;

            ImgCache.options.usePersistentCache = true;

            ImgCache.options.cacheClearSize = -1;
            ImgCache.options.localCacheFolder = 'startups';

            ImgCache.init(function(){
                //console.log('ImgCache.init ');
                $rootScope.$broadcast("cacheCreated");
            }, function(){
                //console.log('ImgCache.init errors');
            });

        },


        cache: function(id, success, fail) {
            var url = "https://tech-start-ups-bayern-app.evobis.de/api/getImage/" + id;
            ImgCache.cacheFile(url, success, fail);
        },

        /*
        useCached: function(img, id) {
            function useFile(element) {
                var src = jq(element).data('src');
                ImgCache.useCachedFile(element);

                if(typeof src != "undefined") {
                    ImgCache.useCachedFileWithSource(element, src);
                } else {
                    ImgCache.useCachedFile(element);
                }
            }

            var url = "https://tech-start-ups-bayern-app.evobis.de/api/getImage/" + id;
            ImgCache.isCached(url, function(path, success){
                if(success){
                    // already cached
                    useFile(img);
                } else {
                    ImgCache.cacheFile(url, function(){

                        useFile(img);
                    }, function() { // error no connection
                        $rootScope.$broadcast("ErrorImageLoad");
                    });

                }
            });
        }
        */

        useCached: function(img, id) {
            var url = "https://tech-start-ups-bayern-app.evobis.de/api/getImage/" + id;
            ImgCache.isCached(url, function(path, success){
                if(success){
                    // already cached
                    ImgCache.useCachedFileWithSource(img, url, function(){
                        //console.log('ImgCache already cached useCachedFileWithSource');
                    });
                } else {
                    ImgCache.cacheFile(url, function(){
                        ImgCache.useCachedFileWithSource(img, url, function(){
                            //console.log('ImgCache not cached useCachedFileWithSource');
                        });
                    }, function() { // error no connection
                        $rootScope.$broadcast("ErrorImageLoad",id);
                    });
                }
            });

        },

        isInCached: function(id) {
            var url = "https://tech-start-ups-bayern-app.evobis.de/api/getImage/" + id;
            ImgCache.isCached(url, function(path, success){
                if(success){
                    // already cached
                    $rootScope.$broadcast("ImageInCache",{inCache:true,imageId:id});
                } else {
                    $rootScope.$broadcast("ImageInCache",{inCache:false,imageId:id});
                }
            });

        }

    }
});

// debounce function from underscore.js MIT licenced
// http://underscorejs.org/underscore.js
services.service('ReactService', ['$timeout', function ($timeout) {
    return {
        debounce : function (func, wait, immediate) {
           var timeout, args, context, timestamp, result;

            var later = function() {
              var last = Date.now() - timestamp;
              if (last < wait) {
                timeout = $timeout(later, wait - last);
              } else {
                timeout = null;
                if (!immediate) {
                  result = func.apply(context, args);
                  context = args = null;
                }
              }
            };

            return function() {
              context = this;
              args = arguments;
              timestamp = Date.now();
              var callNow = immediate && !timeout;
              if (!timeout) {
                timeout = $timeout(later, wait);
              }
              if (callNow) {
                result = func.apply(context, args);
                context = args = null;
              }

              return result;
            };
        }
    }
}]);
